@@ -174,6 +174,21 @@ class Pipeline:
                                   return_svg=return_svg)
         return results
 
+    def translation_result(self, text:list, source_language:str, pipeline) -> list:
+        """It returns the translation results of a text.
+        parameters:
+        ----------------
+        text: list[str]
+        source_language: str
+        target_language: str
+        return:
+        ----------------
+        results: list of dict
+        """
+        from aimped.nlp.translation import split_text, translate
+        translated_text = translate(text=text,source_language=source_language,pipeline = pipeline)
+        return translated_text        
+
     def __str__(self) -> str:
         """Return the string representation of the pipeline."""
         return f"Pipeline(model={self.model}, tokenizer={self.tokenizer})"
